@@ -204,7 +204,7 @@ class Data:
                         'value':'/var/calculate/server-backup/deleted'}
 
     #-----------------------------------------------------
-    #Сервис Unix
+    # Сервис Unix
     #-----------------------------------------------------
     #DN администратора сервиса Unix (он, же DN сервиса)
     ld_unix_dn = {}
@@ -223,7 +223,7 @@ class Data:
                    'value':'off'}
 
     #-----------------------------------------------------
-    #Сервис Samba
+    # Сервис Samba
     #-----------------------------------------------------
     #DN администратора сервиса Samba (он, же DN сервиса)
     ld_samba_dn = {}
@@ -262,7 +262,7 @@ class Data:
                     'value':'off'}
 
     #-----------------------------------------------------
-    #Сервис Mail
+    # Сервис Mail
     #-----------------------------------------------------
     #DN администратора сервиса Mail (он, же DN сервиса)
     ld_mail_dn = {}
@@ -284,7 +284,7 @@ class Data:
                    'value':'off'}
 
     #-----------------------------------------------------
-    #Сервис Jabber
+    # Сервис Jabber
     #-----------------------------------------------------
     #DN администратора сервиса Jabber (он, же DN сервиса)
     ld_jabber_dn = {}
@@ -303,7 +303,7 @@ class Data:
                    'value':'off'}
 
     #-----------------------------------------------------
-    #Сервис FTP
+    # Сервис FTP
     #-----------------------------------------------------
     # имя компьютера с настроенным сервисом FTP
     cl_remote_ftp = {}
@@ -328,7 +328,7 @@ class Data:
     sr_ftp_path = {'value':'/var/calculate/server-data/ftp'}
 
     #-----------------------------------------------------
-    #Сервис Proxy
+    # Сервис Proxy
     #-----------------------------------------------------
     # имя компьютера с настроенным сервисом Proxy
     sr_proxy_host = {}
@@ -364,7 +364,7 @@ class Data:
     cl_name = {'value':'calculate-server'}
 
     # версия программы
-    cl_ver = {'value':'2.1.3'}
+    cl_ver = {'value':'2.1.4'}
 
     #DN LDAP ветки, в котором будут находится служебные ветки
     ld_ldap_dn = {}
@@ -420,6 +420,10 @@ class Data:
     sr_proxy_net_allow = {}
     # Текст в squid.conf - доступные сети
     sr_proxy_net_allow_pass = {}
+    # Доступные сети для сервиса DNS
+    sr_dns_net_allow = {}
+    # Текст в named.conf - доступные сети
+    sr_dns_net_allow_pass = {}
 
     #DN ветки хранения реплицируемых алиасов
     ld_repl_mail_dn = {}
@@ -433,3 +437,32 @@ class Data:
     #Настроен или нет сервис Mail как почтовый релей
     sr_mail_relay_set = {'mode':"w",
                          'value':'off'}
+
+    #-----------------------------------------------------
+    # Сервис DNS
+    #-----------------------------------------------------
+    # имя компьютера с настроенным сервисом DNS
+    sr_dns_host = {}
+
+    #DN администратора сервиса DNS (он, же DN сервиса)
+    ld_dns_dn = {}
+
+    #имя администратора сервиса DNS
+    ld_dns_login = {'value':'DNS'}
+
+    #пароль администратора сервиса DNS
+    ld_dns_pw = {}
+
+    #hash пароля администратора сервиса DNS
+    ld_dns_hash = {}
+
+    #Настроен или нет сервис DNS
+    sr_dns_set = {'mode':"w",
+                  'value':'off'}
+
+    #-----------------------------------------------------
+    # Сервис DHCP
+    #-----------------------------------------------------
+    #Настроен или нет сервис DHCP
+    sr_dhcp_set = {'mode':"w",
+                   'value':'off'}
\ No newline at end of file
